import React, { memo } from 'react';
import { motion } from 'framer-motion';
import Button from '../ui/Button';
import { ArrowRight, Clock, Users, Timer, Activity } from 'lucide-react';
import { Link } from 'react-router-dom';

const Hero = memo(() => {
  const scrollToConsultation = () => {
    const consultationSection = document.getElementById('contact');
    consultationSection?.scrollIntoView({ behavior: 'smooth' });
  };

  const stats = [
    { icon: <Activity className="h-4 w-4 sm:h-5 sm:w-5 md:h-6 md:w-6" />, value: "99.9%", label: "Uptime" },
    { icon: <Clock className="h-4 w-4 sm:h-5 sm:w-5 md:h-6 md:w-6" />, value: "24/7", label: "Support" },
    { icon: <Timer className="h-4 w-4 sm:h-5 sm:w-5 md:h-6 md:w-6" />, value: "Rapid", label: "Response Time" },
    { icon: <Users className="h-4 w-4 sm:h-5 sm:w-5 md:h-6 md:w-6" />, value: "20+", label: "Years Of Experience" }
  ];

  return (
    <div className="relative pt-16 sm:pt-20 w-full overflow-hidden">
      {/* Background image with overlay */}
      <div 
        className="absolute inset-0 z-0 w-full h-full"
        style={{
          backgroundImage: 'url(https://iili.io/FFgg1wX.png)',
          backgroundSize: 'cover',
          backgroundPosition: 'center',
          backgroundRepeat: 'no-repeat',
        }}
      >
        <div className="absolute inset-0 bg-white/75"></div>
      </div>

      {/* Content */}
      <div className="relative z-10 w-full pb-12 sm:pb-16 md:pb-20">
        <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8 py-8 sm:py-12 md:py-16 lg:py-20">
          <div className="grid grid-cols-1 lg:grid-cols-2 gap-6 sm:gap-8 lg:gap-12 items-center mb-8 sm:mb-12 lg:mb-16 w-full">
            {/* Text Content */}
            <motion.div 
              className="order-2 lg:order-1 w-full text-center lg:text-left"
              initial={{ opacity: 0, x: -20 }}
              animate={{ opacity: 1, x: 0 }}
              transition={{ duration: 0.6 }}
            >
              <h1 className="text-2xl sm:text-3xl md:text-4xl lg:text-5xl xl:text-6xl font-bold leading-tight mb-4 sm:mb-6 text-primary">
                Reliable Secure IT Without the Jargon
              </h1>
              <p className="text-base sm:text-lg lg:text-xl text-slate-600 mb-6 sm:mb-8 leading-relaxed max-w-2xl mx-auto lg:mx-0">
                At Jawbone, we handle your tech, so you can focus on growing your business. Our expert IT solutions keep your data safe and your systems running smoothly — no geek speak, just results.
              </p>
              <div className="flex flex-col sm:flex-row gap-3 sm:gap-4 w-full justify-center lg:justify-start">
                <Link to="/contact" className="w-full sm:w-auto">
                  <button className="group bg-emerald text-white px-6 sm:px-8 py-3 sm:py-4 rounded-md transition-all duration-300 transform hover:scale-105 hover:shadow-lg hover:shadow-emerald/30 flex items-center justify-center relative overflow-hidden before:absolute before:inset-0 before:bg-gradient-to-r before:from-transparent before:via-white/20 before:to-transparent before:translate-x-[-100%] hover:before:translate-x-[100%] before:transition-transform before:duration-700 text-sm sm:text-base lg:text-lg w-full">
                    <span className="relative z-10 flex items-center">
                      Get Your Free Assessment
                      <ArrowRight className="ml-2 h-4 w-4 sm:h-5 sm:w-5 transform group-hover:translate-x-1 transition-transform duration-300" />
                    </span>
                  </button>
                </Link>
                <Link to="/contact" className="w-full sm:w-auto">
                  <button className="group border-2 border-emerald text-emerald px-6 sm:px-8 py-3 sm:py-4 rounded-md transition-all duration-300 hover:bg-emerald hover:text-white transform hover:scale-105 hover:shadow-lg relative overflow-hidden text-center text-sm sm:text-base lg:text-lg w-full">
                    <span className="relative z-10">Contact Us</span>
                  </button>
                </Link>
              </div>
            </motion.div>

            {/* Image */}
            <motion.div 
              className="order-1 lg:order-2 relative group w-full"
              initial={{ opacity: 0, x: 20 }}
              animate={{ opacity: 1, x: 0 }}
              transition={{ duration: 0.6, delay: 0.2 }}
            >
              <div className="absolute inset-0 bg-gradient-to-r from-secondary to-emerald rounded-lg blur-xl opacity-20 group-hover:opacity-30 transition-opacity duration-500"></div>
              <img 
                src="https://iili.io/FF4IrYX.png" 
                alt="IT professionals working"
                className="rounded-lg shadow-2xl transform hover:scale-105 transition-transform duration-300 relative w-full h-auto max-w-full"
              />
            </motion.div>
          </div>

          {/* Decorative Line with single circle */}
          <div className="relative mb-6 sm:mb-8 lg:mb-12 w-full">
            <div className="absolute inset-0 flex items-center">
              <div className="w-full border-t border-slate-200"></div>
            </div>
            <div className="relative flex justify-center">
              <div className="bg-white px-2">
                <div className="h-3 w-3 rounded-full bg-emerald"></div>
              </div>
            </div>
          </div>

          {/* Stats Section - Improved mobile layout */}
          <div className="w-full max-w-6xl mx-auto mb-6 sm:mb-8">
            <div className="grid grid-cols-2 lg:grid-cols-4 gap-3 sm:gap-4 lg:gap-6">
              {stats.map((stat, index) => (
                <motion.div
                  key={index}
                  initial={{ opacity: 0, y: 20 }}
                  animate={{ opacity: 1, y: 0 }}
                  transition={{ delay: 0.4 + 0.1 * index, duration: 0.5 }}
                  className="bg-white/90 backdrop-blur-sm rounded-xl p-3 sm:p-4 lg:p-6 shadow-lg hover:shadow-xl transition-all duration-300 border border-slate-100 group hover:border-secondary/20 text-center w-full flex flex-col justify-center items-center"
                  style={{ minHeight: '100px' }}
                >
                  <div className="flex justify-center mb-2 sm:mb-3">
                    <div className="text-secondary group-hover:scale-110 transition-transform duration-300">
                      {stat.icon}
                    </div>
                  </div>
                  <div className="text-lg sm:text-xl lg:text-2xl xl:text-3xl font-bold text-secondary mb-1 sm:mb-2 leading-tight">
                    {stat.value}
                  </div>
                  <div className="text-xs sm:text-sm lg:text-base text-slate-600 font-medium leading-tight text-center px-1">
                    {stat.label}
                  </div>
                </motion.div>
              ))}
            </div>
          </div>
        </div>
      </div>
    </div>
  );
});

Hero.displayName = 'Hero';

export default Hero;